// For compilers that supports precompilation , includes "wx/wx.h"
#include "wx/wxprec.h"

#ifndef WX_PRECOMP
	#include "wx/wx.h"
#endif

#include "TextFrame.h"

#include "wx/colordlg.h"
#include "wx/fontdlg.h"

TextFrame::TextFrame(const wxChar *title, int xpos, int ypos, int width, int height)
	: wxFrame((wxFrame *) NULL, -1, title, wxPoint(xpos, ypos), wxSize(width, height))
{
  m_pTextCtrl = new wxTextCtrl(this, -1, wxString("Type some text..."),
							   wxDefaultPosition, wxDefaultSize, wxTE_MULTILINE);

  m_pMenuBar = new wxMenuBar();

  // File Menu
  m_pFileMenu = new wxMenu();
  m_pFileMenu->Append(MENU_FILE_OPEN, "&Open", "Opens an existing file");
  m_pFileMenu->Append(MENU_FILE_SAVE, "&Save", "Save the content");
  m_pFileMenu->AppendSeparator();
  m_pFileMenu->Append(MENU_FILE_QUIT, "&Quit", "Quit the application");
  m_pMenuBar->Append(m_pFileMenu, "&File");

  // Option Menu
  m_pOptionMenu = new wxMenu();
  m_pOptionMenu->Append(MENU_OPTION_BACKGROUND, "&Background", "Sets the background colour of the editor");
  m_pOptionMenu->Append(MENU_OPTION_FONT, "&Font", "Sets the font of the editor");
  m_pOptionMenu->Append(MENU_OPTION_DIRECTORY, "&Directory", "Sets the working directory");
  m_pMenuBar->Append(m_pOptionMenu, "&Options");

  // About menu
  m_pInfoMenu = new wxMenu();
  m_pInfoMenu->Append(MENU_INFO_ABOUT, "&About", "Shows information about the application");
  m_pMenuBar->Append(m_pInfoMenu, "&Info");

	SetMenuBar(m_pMenuBar);

  // Statusbar
  CreateStatusBar(3);
  SetStatusText("Ready", 0);
 }

TextFrame::~TextFrame()
{
}

void TextFrame::OnMenuFileOpen(wxCommandEvent &event)
{
  wxFileDialog *dlg = new wxFileDialog(this, "Open a text file",
									   "", "", "All files(*.*)|*.*|Text Files(*.txt)|*.txt",
									   wxOPEN, wxDefaultPosition);
  if ( dlg->ShowModal() == wxID_OK )
  {
	m_pTextCtrl->LoadFile(dlg->GetFilename());
	SetStatusText(dlg->GetFilename(), 0);
  }
  dlg->Destroy();
}

void TextFrame::OnMenuFileSave(wxCommandEvent &event)
{
  wxFileDialog *dlg = new wxFileDialog(this, "Save a text file",
									   "", "", "All files(*.*)|*.*|Text Files(*.txt)|*.txt",
									   wxSAVE, wxDefaultPosition);
  if ( dlg->ShowModal() == wxID_OK )
  {
	m_pTextCtrl->SaveFile(dlg->GetPath());
	SetStatusText(dlg->GetFilename(), 0);
  }
  dlg->Destroy();
  m_pTextCtrl->DiscardEdits();
}

void TextFrame::OnMenuFileQuit(wxCommandEvent &event)
{
  Close(FALSE);
}

void TextFrame::OnMenuInfoAbout(wxCommandEvent &event)
{
  wxLogMessage("File About Menu Selected");
}

void TextFrame::OnMenuOptionBackgroundColor(wxCommandEvent &event)
{
  wxColourData colourData;
  wxColour colour = m_pTextCtrl->GetBackgroundColour();
  colourData.SetColour(colour);
  colourData.SetChooseFull(true);
  wxColourDialog *dlg = new wxColourDialog(this, &colourData);
  if ( dlg->ShowModal() == wxID_OK )
  {
	colourData = dlg->GetColourData();
	m_pTextCtrl->SetBackgroundColour(colourData.GetColour());
	m_pTextCtrl->Refresh();
  }
  dlg->Destroy();
}

void TextFrame::OnMenuOptionFont(wxCommandEvent& event)
{
  wxFontData fontData;
  wxFont font;
  wxColour colour;

  font = m_pTextCtrl->GetFont();
  fontData.SetInitialFont(font);
  colour = m_pTextCtrl->GetForegroundColour();
  fontData.SetColour(colour);
  fontData.SetShowHelp(true);

  wxFontDialog *dlg = new wxFontDialog(this, &fontData);
  if ( dlg->ShowModal() == wxID_OK )
  {
	fontData = dlg->GetFontData();
	font = fontData.GetChosenFont();
	m_pTextCtrl->SetFont(font);
	m_pTextCtrl->SetForegroundColour(fontData.GetColour());
	m_pTextCtrl->Refresh();
  }
  dlg->Destroy();
}

void TextFrame::OnMenuOptionDirectory(wxCommandEvent& event)
{
  wxDirDialog *dlg = new wxDirDialog(this, "Select a new working directory", wxGetCwd());
  if ( dlg->ShowModal() == wxID_OK )
  {
	wxSetWorkingDirectory(dlg->GetPath());
  }
  dlg->Destroy();
}

void TextFrame::OnClose(wxCloseEvent& event)
{
  bool destroy = true;

  if ( event.CanVeto() )
  {
	if ( m_pTextCtrl->IsModified() )
	{
	  wxMessageDialog *dlg = new wxMessageDialog(this, "Text is changed!\nAre you sure you want to exit?",
												 "Text changed!!!", wxYES_NO | wxNO_DEFAULT);
	  int result = dlg->ShowModal();
	  if ( result == wxID_NO )
	  {
		event.Veto();
		destroy = false;
	  }
	  dlg->Destroy();
	}
  }
  if ( destroy )
  {
	Destroy();
  }
}

BEGIN_EVENT_TABLE(TextFrame, wxFrame)
   EVT_MENU(MENU_FILE_OPEN, TextFrame::OnMenuFileOpen)
   EVT_MENU(MENU_FILE_SAVE, TextFrame::OnMenuFileSave)
   EVT_MENU(MENU_FILE_QUIT, TextFrame::OnMenuFileQuit)
   EVT_MENU(MENU_INFO_ABOUT, TextFrame::OnMenuInfoAbout)
   EVT_MENU(MENU_OPTION_BACKGROUND, TextFrame::OnMenuOptionBackgroundColor)
   EVT_MENU(MENU_OPTION_FONT, TextFrame::OnMenuOptionFont)
   EVT_MENU(MENU_OPTION_DIRECTORY, TextFrame::OnMenuOptionDirectory)
   EVT_CLOSE(TextFrame::OnClose)
END_EVENT_TABLE()


