#include "wx/wxprec.h"
#define DEBUG 1
#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif

#include "DimTextCtrl.h"
#include "GotoLineDialog.h"
#include "RangeValidator.h"

GotoLineDialog::GotoLineDialog(wxWindow *parent)
    : wxDialog(parent, -1, "Goto Line...", wxDefaultPosition,
               wxSize(250, 120), wxDEFAULT_DIALOG_STYLE)
{
  m_lineNumber = "1";
  SetAutoLayout(TRUE);

  wxLayoutConstraints *layout = new wxLayoutConstraints();

  // Label is centered on the dialog and on top of the dialog.
  m_pLabel = new wxStaticText(this, -1, "");
  layout->top.SameAs(this, wxTop, 10);
  layout->centreX.SameAs(this, wxCentreX);
  layout->width.AsIs();
  layout->height.AsIs();
  m_pLabel->SetConstraints(layout);

  // LineNumberCtrl is centered on the dialog and below Label.
  m_pLineNumberCtrl = new wxTextCtrl(this, -1);
  layout = new wxLayoutConstraints();
  layout->top.Below(m_pLabel, 10);
  layout->centreX.SameAs(this, wxCentreX);
  layout->width.Absolute(70);
  layout->height.AsIs();
  m_pLineNumberCtrl->SetConstraints(layout);

  // cancelButton is put at the right and bottom of the dialog.
  wxButton *cancelButton = new wxButton(this, wxID_CANCEL, "Cancel");
  layout = new wxLayoutConstraints();
  layout->bottom.SameAs(this, wxBottom, 10);
  layout->right.SameAs(this, wxRight, 10);
  layout->width.AsIs();
  layout->height.AsIs();
  cancelButton->SetConstraints(layout);

  // okButton is put at the left of the cancelButton.
  wxButton *okButton = new wxButton(this, wxID_OK, "Ok");
  layout = new wxLayoutConstraints();
  layout->bottom.SameAs(cancelButton, wxBottom);
  layout->right.LeftOf(cancelButton, 10);
  layout->width.SameAs(cancelButton, wxWidth);
  layout->height.AsIs();
  okButton->SetConstraints(layout);
}

void GotoLineDialog::OnInitDialog(wxInitDialogEvent &event)
{
  wxString label = m_lineNumber;

  label.Printf("Enter a line between 1 and %ld", m_maxLineNumber);
  m_pLabel->SetLabel(label);
  Layout();

  RangeValidator rangeValidator(&m_lineNumber, 1, m_maxLineNumber);
  m_pLineNumberCtrl->SetValidator(rangeValidator);

  TransferDataToWindow();

  m_pLineNumberCtrl->SetFocus();
}

long GotoLineDialog::GetLineNumber()
{
  // Return 0 when toLong fails.
  long lineNumber;
  return m_lineNumber.ToLong(&lineNumber) ? lineNumber : 0;
}

BEGIN_EVENT_TABLE(GotoLineDialog, wxDialog)
  EVT_INIT_DIALOG(GotoLineDialog::OnInitDialog)
END_EVENT_TABLE()

