// For compilers that supports precompilation , includes "wx/wx.h"
#include "wx/wxprec.h"

#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif

#include "RangeValidator.h"

RangeValidator::RangeValidator(const RangeValidator &toCopy)
{
  Copy(toCopy);
}

wxObject* RangeValidator::Clone() const
{
  return new RangeValidator(*this);
}

bool RangeValidator::Copy(const RangeValidator& val)
{
  wxValidator::Copy(val);

  m_min   = val.m_min;
  m_max   = val.m_max;
  m_value = val.m_value;

  return true;
}

bool RangeValidator::Validate(wxWindow *parent)
{
  wxWindow *win = GetWindow();
  if ( !win )
     return false;
  wxTextCtrl *control = (wxTextCtrl*) win;

  wxString message;
  bool result = false;

  wxString currentValue = control->GetValue();

    long value;
    if ( ! currentValue.ToLong(&value) )
    {
      message.Printf("%s is not a valid number", currentValue.c_str());
    }
    else
    {
      if (    value < m_min
           || value > m_max )
      {
        message.Printf("%ld is not between %ld and %ld", value, m_min, m_max);
      }
      else
      {
          result = true;
      }
    }

  if ( ! result )
  {
    wxMessageBox(message);
    control->SetFocus();
  }

  return result;
}

bool RangeValidator::TransferToWindow()
{
  wxWindow *win = GetWindow();
  if ( ! win )
     return false;
  if ( ! m_value )
     return false;
  if ( ! win->IsKindOf(CLASSINFO(wxTextCtrl)) )
      return false;

  wxTextCtrl *control = (wxTextCtrl*) win;
  control->SetValue(*m_value);

  return true;
}

bool RangeValidator::TransferFromWindow()
{
  wxWindow *win = GetWindow();
  if ( ! win )
     return false;
  if ( ! m_value )
     return false;
  if ( ! win->IsKindOf(CLASSINFO(wxTextCtrl)) )
      return false;

  wxTextCtrl *control = (wxTextCtrl*) win;
  *m_value = control->GetValue();

  return true;
}


