#ifndef _RANGE_VALIDATOR_H
#define _RANGE_VALIDATOR_H

/**
 * RangeValidator. Checks if an entered value is in a given range.
 */

class RangeValidator : public wxValidator
{
public:
  /**
   * Constructor.
   */
  RangeValidator(wxString *value, long min, long max)
     : m_min(min), m_max(max), m_value(value) {}

  /**
   * Copy constructor
   */
  RangeValidator(const RangeValidator &toCopy);

  /**
   * Returns a copy of this validator
   */
  virtual wxObject* Clone() const;

  /**
   * Validate. Returns true when the entered value is correct, otherwise false
   */
  bool Validate(wxWindow *parent);

  /**
   * Transfer the data to the window. Returns false when there's a problem.
   */
  bool TransferToWindow();
  /**
   * Transfer the data from the window. Returns false when there's a problem.
   */
  bool TransferFromWindow();

protected:

  /**
   * Copies the given RangeValidator to this RangeValidator
   */
  bool Copy(const RangeValidator& val);

private:
  long m_min;
  long m_max;
  wxString *m_value;
};

#endif // _RANGE_VALIDATOR_H

