// For compilers that supports precompilation , includes "wx/wx.h"
#include "wx/wxprec.h"

#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif

#include "DimTextCtrl.h"

BEGIN_EVENT_TABLE(DimTextCtrl, wxTextCtrl)
   EVT_PAINT(DimTextCtrl::OnPaint)
   EVT_SET_FOCUS(DimTextCtrl::OnSetFocus)
   EVT_KILL_FOCUS(DimTextCtrl::OnKillFocus)
END_EVENT_TABLE()

DimTextCtrl::DimTextCtrl(wxWindow *parent,
                         wxWindowID id,
                         const wxString& dim,
                         const wxColour& dimColour,
                         const wxString& value,
                         const wxPoint& pos,
                         const wxSize& size,
                         long style,
                         const wxValidator& validator,
                         const wxString& name) :
      wxTextCtrl(parent, id, value, pos, size, style, validator, name)
{
  m_dimText = dim;
  m_dimColour = dimColour;
  m_isDimmed = true;
}

void DimTextCtrl::OnPaint(wxPaintEvent &event)
{
  wxPaintDC paintDC(this);

  wxSize clientSize = GetClientSize();

  // Redraw background
  paintDC.SetPen(*wxTRANSPARENT_PEN);
  wxBrush brush(wxSystemSettings::GetSystemColour(wxSYS_COLOUR_WINDOW), wxSOLID);
  paintDC.SetBrush(brush);
  paintDC.DrawRectangle(wxPoint(0, 0), clientSize);

  if ( IsDimmed() ) // Draw the dimmed text.
  {
    paintDC.SetFont(GetFont());
    paintDC.SetTextForeground(m_dimColour);
    wxCoord width;
    wxCoord height;
    paintDC.GetTextExtent(m_dimText, &width, &height);
    if ( width > clientSize.GetWidth() )
       width = clientSize.GetWidth();
    if ( height > clientSize.GetHeight() )
       height = clientSize.GetHeight();
    paintDC.SetClippingRegion(0, 0, width, height);
    paintDC.DrawText(m_dimText, 0, 0);
  }
  else
  {
    event.Skip();
  }
}

void DimTextCtrl::OnSetFocus(wxFocusEvent &event)
{
  event.Skip();
  // When the control gets the focus and the dim text is shown,
  // Refresh the control and erase the dimmed text.
  SetDimmed(GetValue().Length() != 0);
}

void DimTextCtrl::OnKillFocus(wxFocusEvent &event)
{
  event.Skip();
  // When the control loses the focus and the length of the value is 0
  // Draw the dim texted
  SetDimmed(GetValue().Length() == 0);
}

